@@ -8,16 +8,14 @@ The estimation itself can be performed with the :func:`spectrum.mtm.pmtm` functi
 
 
 """
-import numpy
-from numpy.fft import fft
-from psd import FourierSpectrum
-
 import numpy as np
 import ctypes
 from ctypes import *
 import ctypes as C
 import platform
 import os
+from ctypes import POINTER
+import os
 from os.path import join as pj
 from spectrum.tools import nextpow2
 from pylab import semilogy
@@ -52,7 +50,7 @@ p = os.path.abspath(os.path.dirname(__file__))
 mtspeclib = ctypes.cdll.LoadLibrary(pj(p, lib_name))
 
 
-def mtm(x, NW=None, k=None, NFFT=None, e=None, v=None, method='adapt', show=True):
+def pmtm(x, NW=None, k=None, NFFT=None, e=None, v=None, method='adapt', show=True):
     """Multitapering spectral estimation
 
     :param array x: the data
@@ -500,71 +498,3 @@ def _fftconvolve(in1, in2, mode="full", axis=None):
         return _centered(ret,osize)
     elif mode == "valid":
         return _centered(ret,abs(s2-s1)+1)
-"""Correlogram PSD estimates
-
-.. topic:: This module provides Correlograms methods 
-
-    .. autosummary::
-
-        CORRELOGRAMPSD
-        pcorrelogram
-        
-    .. codeauthor:: Thomas Cokelaer 2011
- 
-    :References: See [Marple]_
-"""
-
-
-
-
-class pmtm(FourierSpectrum):
-    """The MTM provides an interface to :func:`mtm`.
-    
-    It returns an object that inherits from :class:`FourierSpectrum` and 
-    therefore ease the manipulation of PSDs.
-       
-    .. plot::
-        :width: 80%
-        :include-source:
-        
-        from spectrum import *
-        p = pmtm(data_cosine(N=1024))
-        p()
-        p.plot()
-        p.plot(sides='twosided')
-    
-    """
-    def __init__(self, data, NW=2.5, k=3, NFFT=None, method='adapt', sampling=1.):
-        """**Correlogram Constructor**
-        
-        :param array data:     input data (list or numpy.array)
-        :param float sampling: sampling frequency of the input :attr:`data`.
-        :param int NFFT:       total length of the final data sets (padded with zero if needed; default is 4096)
-        
-        """
-        super(pmtm, self).__init__(data, NFFT=NFFT, sampling=sampling)
-        self.method = method
-        self.NW = NW
-        self.k = k
-
-    def __call__(self):
-        psd = mtm(self.data, NW=self.NW, k=self.k, method=self.method, NFFT=self.NFFT, show=False)
-        
-        if self.datatype == 'real':
-            newpsd  = psd[0:self.NFFT/2] * 2
-            newpsd[0] /= 2.
-            newpsd = numpy.append(newpsd, psd[0])
-            self.psd = newpsd
-        else:
-            self.psd = psd
-        #self.scale()
-        
-    def _str_title(self):
-        return "Multi tapering estimate\n"
-    
-    def __str__(self):
-        return super(pmtm, self).__str__()
-
-
-
-
